# -*- coding: utf-8 -*-

from kobo.django.django_version import django_version_ge
if django_version_ge("2.0"):
    from django.urls import re_path as url
    
else:
    from django.conf.urls import url
import kobo.django.upload.views


urlpatterns = [
    url(r"^$", kobo.django.upload.views.file_upload),
]



import six

if six.PY2:
    # Ancient cases: force_text and ugettext are the unicode-aware variants
    from django.utils.translation import ugettext_lazy as gettext_lazy
    from django.utils.encoding import force_text as force_str
else:
    # Modern (py3-only) case
    from django.utils.translation import gettext_lazy
    from django.utils.encoding import force_str


__all__ = ["gettext_lazy", "force_str"]



import sys
from xmlrpc.client import Fault
import json

from kobo.client import ClientCommand


class Create_Worker(ClientCommand):
    """create a worker"""
    enabled = True
    admin = True


    def options(self):
        self.parser.usage = "%%prog %s worker_name [worker_name]" % self.normalized_name

    def run(self, *args, **kwargs):
        if not args:
            self.parser.error("No worker name specified.")

        username = kwargs.pop("username", None)
        password = kwargs.pop("password", None)
        hub = kwargs.pop("hub", None)
        workers = args

        self.set_hub(username, password, hub)
        for worker in workers:
            try:
                new_worker = self.hub.client.create_worker(worker)
                print(json.dumps(new_worker))
            except Fault as ex:
                print(repr(ex), file=sys.stderr)
                # Exit on first xmlrpc failure
                # It's very likely user is not admin
                raise
